Attribute VB_Name = "modTest"
' **************************************************************************
'
'  Program:       VB5 Code Timer Utility
'
'  Written By:    Rich By  73553.774@compuserve.com
'
'  Version:       1.00.0001  (written 11/30/97)
'
'  Comments:      To add a new test add a new item in the LoadTestList sub
'                 then add the corresponding case in the RunTest sub.  If
'                 you have questions or comments feel free to contact me at
'                 the above address.
'
'  Module Descr:  Test routines
'
' **************************************************************************
Option Explicit

Private Function ChangeLoops(nMax As Long) As Long
'
'  Called from specific test cases in the RunTest sub, this
'  function adjusts the user-selected number of iterations
'  for specific tests which are known to require a long
'  time to complete.
'
   Screen.MousePointer = vbDefault
   MsgBox "This will take a long time.  Automatically" & vbCrLf & "changing the number of iterations to " & Format$(nMax, "#,##0") & ".", vbInformation, gstrTitle
   ChangeLoops = nMax
   Screen.MousePointer = vbHourglass
 
End Function

Public Sub RunTest(lCnt As Long, iTestType As Integer)
'
'  Run selected time test.  To add a new test add a new item in
'  the LoadTestList sub then add the corresponding case below.
'
'  Do not execute DoEvents during the test loops - this will result
'  in unpredictable results.  Most tests can be executed in under
'  one second with fairly accurate results.  If you define a new
'  test that takes a long time (String ops, for example) you can
'  force the max number of iterations by adding the following line
'  immediately after the Case statement:
'
'     lCnt = ChangeLoops(N)
'
'  ...where lCnt is the initial number of loops and N is max number
'  of loops appropriate for this test.
'
   Const ONE_HUNDRED% = 100
   Dim x As Long
   Dim strTab As String
   Dim iTest As Integer
   Dim iTestB As Integer
   Dim lTest As Long
   Dim sTest As Single
   Dim sTestB As Single
   Dim sTestC As Single
   Dim dTest As Double
   Dim lStart As Long
   Dim lEnd As Long
   Dim lResult As Long
   Dim strTest As String
   Dim strResult1 As String
   Dim strResult2 As String
   Dim strResult3 As String
   Dim strLine As String
   Dim strMsg As String
   Dim strRetA As String
   Dim strRetB As String
   Dim strCode As String
   Dim iRet As Integer
   Dim iHeight As Integer
   Dim iWidth As Integer
   Dim iNSecs As Integer
   Dim iIntArray() As Integer
'
'  Check for unused tests
'
   If LCase$(Left(frmMain!lstTest.Text, 6)) = "unused" Then
      MsgBox "This test is currently not in use.", vbInformation, gstrTitle
      Exit Sub
   Else
      strTest = frmMain!lstTest.Text & " Test:" & vbCrLf & vbCrLf
   End If
   strTab = Space$(6) 'for results msgbox
   strLine = String$(48, "_") 'for results msgbox
'
'  Run the test...
'
   Select Case iTestType
      Case 0
         strTest = "Empty For Loop Test:"
         lStart = timeGetTime()
         For x = 1 To lCnt
         Next
      Case 1
         If lCnt > 32000 Then lCnt = 32000
         strTest = strTest & strTab & "iTest = iTest + 1" & strTab & "' increment short counter"
         strCode = "iTest = iTest + 1"
         lStart = timeGetTime()
         For x = 1 To lCnt
            iTest = iTest + 1
         Next
      Case 2
         strTest = strTest & strTab & "lTest = lTest + 1" & strTab & "' increment long counter"
         strCode = "lTest = lTest + 1"
         lStart = timeGetTime()
         For x = 1 To lCnt
            lTest = lTest + 1
         Next
      Case 3
         strTest = strTest & strTab & "sTest = sTest + 1" & strTab & "' increment single value"
         strCode = "sTest = sTest + 1"
         lStart = timeGetTime()
         For x = 1 To lCnt
            sTest = sTest + 1
         Next
      Case 4
         lCnt = ChangeLoops(5000)
         strTest = strTest & strTab & "On Error Resume Next" & strTab & "' enable trap" & vbCrLf & strTab & "lTest = lTest / 0" & strTab & "' force error" & vbCrLf & strTab & "On Error GoTo 0" & strTab & "' disable trap"
         strCode = "On Error Resume Next" & vbCrLf & "lTest = lTest / 0" & vbCrLf & "On Error GoTo 0"
         lStart = timeGetTime()
         For x = 1 To lCnt
            On Error Resume Next
            lTest = lTest / 0
            On Error GoTo 0
         Next
      Case 5
         strTest = strTest & strTab & "On Error Resume Next" & strTab & "' enable trap" & vbCrLf & strTab & "On Error GoTo 0" & strTab & "' disable trap"
         strCode = "On Error Resume Next" & vbCrLf & "On Error GoTo 0"
         lStart = timeGetTime()
         For x = 1 To lCnt
            On Error Resume Next
            On Error GoTo 0
         Next
      Case 6
         lCnt = ChangeLoops(5000)
         strTest = strTest & strTab & "' note that trap is only enabled once, before loop" & vbCrLf & strTab & "lTest = lTest / 0" & strTab & "' force error"
         strCode = "lTest = lTest / 0"
         lStart = timeGetTime()
         On Error Resume Next
         For x = 1 To lCnt
            lTest = lTest / 0
         Next
         On Error GoTo 0
      Case 7
         strTest = strTest & strTab & "Call T_NearEmptySub()" & strTab & "' lives in same module"
         strCode = "Call T_NearEmptySub"
         lStart = timeGetTime()
         For x = 1 To lCnt
            Call T_NearEmptySub
         Next
      Case 8
         strTest = strTest & strTab & "Call T_FarEmptySub()" & strTab & "' lives in different module"
         strCode = "Call T_FarEmptySub"
         lStart = timeGetTime()
         For x = 1 To lCnt
            Call T_FarEmptySub
         Next
      Case 9
         strTest = strTest & strTab & "Call T_NearPass1EmptySub(iTest)" & strTab & "' pass an integer"
         strCode = "Call T_NearPass1EmptySub(iTest)"
         lStart = timeGetTime()
         For x = 1 To lCnt
            Call T_NearPass1EmptySub(iTest)
         Next
      Case 10
         strTest = strTest & strTab & "' pass int, lng, sng, dbl" & vbCrLf & strTab & "Call T_NearPass4EmptySub(iTest, lTest, sTest, dTest)"
         strCode = "Call T_NearPass4EmptySub(iTest, lTest, _" & vbCrLf & "sTest, dTest)"
         lStart = timeGetTime()
         For x = 1 To lCnt
            Call T_NearPass4EmptySub(iTest, lTest, sTest, dTest)
         Next
      Case 11
         strTest = strTest & strTab & "If iTest = iTestB Then iTestB = iTest   ' no End If"
         strCode = "If iTest = iTestB Then iTestB = iTest"
         lStart = timeGetTime()
         For x = 1 To lCnt
            If iTest = iTestB Then iTestB = iTest
         Next
      Case 12
         strTest = strTest & strTab & "If iTest = iTestB Then" & vbCrLf & strTab & "    iTestB = iTest" & vbCrLf & strTab & "End If"
         strCode = "If iTest = iTestB Then" & vbCrLf & "   iTestB = iTest" & vbCrLf & "End If"
         lStart = timeGetTime()
         For x = 1 To lCnt
            If iTest = iTestB Then
               iTestB = iTest
            End If
         Next
      Case 13
         strTest = strTest & strTab & "iTest = 100   ' direct numeric assignment"
         strCode = "iTest = 100"
         lStart = timeGetTime()
         For x = 1 To lCnt
            iTest = 100
         Next
      Case 14
         strTest = strTest & strTab & "iTest = ONE_HUNDRED%   ' locally declared constant"
         strCode = "iTest = ONE_HUNDRED%"
         lStart = timeGetTime()
         For x = 1 To lCnt
            iTest = ONE_HUNDRED%
         Next
      Case 15
         'unused
      Case 16
         strTest = strTest & strTab & "sTest = sTest * sTest"
         strCode = "sTest = sTest * sTest"
         lStart = timeGetTime()
         For x = 1 To lCnt
            sTest = sTest * sTest
         Next
      Case 17
         'unused
      Case 18
         'unused
      Case 19
         lCnt = ChangeLoops(5000)
         strTest = strTest & strTab & "On Error Resume Next" & strTab & "' enable trap" & vbCrLf & strTab & "lTest = lTest * lTest" & strTab & "' force error (lTest = 2147483647)" & vbCrLf & strTab & "On Error GoTo 0" & strTab & "' disable trap"
         strCode = "On Error Resume Next" & vbCrLf & "lTest = lTest * lTest 'overflow" & vbCrLf & "On Error GoTo 0"
         lTest = 2147483647
         lStart = timeGetTime()
         For x = 1 To lCnt
            On Error Resume Next
            lTest = lTest * lTest
            On Error GoTo 0
         Next
      Case 20
         strTest = strTest & strTab & "If sTest < 1.843909E+19 And sTestB < 1.843909E+19 Then sTestC = sTest * sTestB"
         strCode = "If sTest < 1.843909E+19 And sTestB _" & vbCrLf & "< 1.843909E+19 Then sTestC = sTest * sTestB"
         sTest = 100000
         sTestB = 100000
         lStart = timeGetTime()
         For x = 1 To lCnt
            If sTest < 1.843909E+19 And sTestB < 1.843909E+19 Then sTestC = sTest * sTestB
         Next
      Case 21
         'unused
      Case 22
         strTest = strTest & strTab & "iTest = Abs(iTestB)" & strTab & "' iTestB = -100"
         strCode = "iTest = Abs(iTestB)"
         lStart = timeGetTime()
         iTestB = -100
         For x = 1 To lCnt
            iTest = Abs(iTestB)
         Next
      Case 23
         strTest = strTest & strTab & "iTest = iTestB" & strTab & "' iTestB = 25"
         strCode = "iTest = iTestB"
         lStart = timeGetTime()
         iTestB = 25
         For x = 1 To lCnt
            iTest = iTestB
         Next
      Case 24
         strTest = strTest & strTab & "On Error Resume Next" & strTab & "' enable trap" & vbCrLf & strTab & "sTest = sTest * sTest" & strTab & "' force error (sTest = 3E+38)" & vbCrLf & strTab & "On Error GoTo 0" & strTab & "' disable trap"
         strCode = "On Error Resume Next" & vbCrLf & "sTest = sTest * sTest 'overflow" & vbCrLf & "On Error GoTo 0"
         sTest = 3E+38
         lStart = timeGetTime()
         For x = 1 To lCnt
            On Error Resume Next
            sTest = sTest * sTest
            On Error GoTo 0
         Next
      Case 25
         strTest = strTest & strTab & "' Public giIntArray() as Integer declared at module level" & vbCrLf & strTab & "Redim Preserve giIntArray(1 to 20)"
         strCode = "ReDim Preserve giIntArray(1 To 20)"
         lStart = timeGetTime()
         For x = 1 To lCnt
            ReDim Preserve giIntArray(1 To 20)
         Next
      Case 26
         strTest = strTest & strTab & "' iIntArray() as Integer declared at Sub level" & vbCrLf & strTab & "Redim Preserve iIntArray(1 to 20)"
         strCode = "ReDim Preserve iIntArray(1 To 20)"
         lStart = timeGetTime()
         For x = 1 To lCnt
            ReDim Preserve iIntArray(1 To 20)
         Next
      Case 27
         strTest = strTest & strTab & "' Public gsSngArray() as Single declared at module level" & vbCrLf & strTab & "Redim Preserve gsSngArray(1 to 20)"
         strCode = "ReDim Preserve gsSngArray(1 To 20)"
         lStart = timeGetTime()
         For x = 1 To lCnt
            ReDim Preserve gsSngArray(1 To 20)
         Next
      Case 28
         strTest = strTest & strTab & "' Public giUBArray(1 to 20) as Integer declared at module level" & vbCrLf & strTab & "iTest = UBound(giUBArray)"
         strCode = "iTest = UBound(giUBArray)"
         lStart = timeGetTime()
         For x = 1 To lCnt
            iTest = UBound(giUBArray)
         Next
      Case 29
         lCnt = ChangeLoops(5000)
         strTest = strTest & strTab & "' sTestB = 99.9999075" & vbCrLf & strTab & "strRetA = Format$(sTestB, ""0.0###"")"
         strCode = "strRetA = Format$(sTestB, ""0.0###"")"
         sTestB = 99.9999075
         lStart = timeGetTime()
         For x = 1 To lCnt
            strRetA = Format$(sTestB, "0.0###")
         Next
      Case 30
         lCnt = ChangeLoops(5000)
         strTest = strTest & strTab & "' sTestB = 99.9999075" & vbCrLf & strTab & "strRetA = Format(sTestB, ""0.0###"")"
         strCode = "strRetA = Format(sTestB, ""0.0###"")"
         sTestB = 99.9999075
         lStart = timeGetTime()
         For x = 1 To lCnt
            strRetA = Format(sTestB, "0.0###")
         Next
      Case 31
         lCnt = ChangeLoops(25000)
         strTest = strTest & strTab & "strRetA = frmMain!lblCount.Caption"
         strCode = "strRetA = frmMain!lblCount.Caption"
         lStart = timeGetTime()
         For x = 1 To lCnt
            strRetA = frmMain!lblCount.Caption
         Next
      Case 32
         'unused
     Case 33
         lCnt = ChangeLoops(25000)
         strTest = strTest & strTab & "strRetA = lblCount" & strTab & "'.Caption is default property"
         strCode = "strRetA = lblCount"
         lStart = timeGetTime()
         For x = 1 To lCnt
            strRetA = frmMain!lblCount
         Next
      Case 34
         strTest = strTest & strTab & "strRetA = strRetB" & strTab & "'strRetB = ""Test String"""
         strCode = "strRetA = strRetB"
         lStart = timeGetTime()
         strRetB = "Test String"
         For x = 1 To lCnt
            strRetA = strRetB
         Next
      Case 35
         strTest = strTest & strTab & "lTest = RGB(255,255,255)"
         strCode = "lTest = RGB(255, 255, 255)"
         lStart = timeGetTime()
         For x = 1 To lCnt
            lTest = RGB(255, 255, 255)
         Next
      Case 36
         strTest = strTest & strTab & "iTest = QBColor(15)"
         strCode = "lTest = QBColor(15)"
         lStart = timeGetTime()
         For x = 1 To lCnt
            lTest = QBColor(15)
         Next
      Case 37
         strTest = strTest & strTab & "strRetA = Trim(test.strA)" & strTab & "'test.strA is a 30 char fixed string type"
         strCode = "strRetA = Trim(Test.strA)"
         lStart = timeGetTime()
         For x = 1 To lCnt
            strRetA = Trim(test.strA)
         Next
      Case 38
         strTest = strTest & strTab & "strRetA = Trim$(test.strA)" & strTab & "'test.strA is a 30 char fixed string type"
         strCode = "strRetA = Trim$(Test.strA)"
         lStart = timeGetTime()
         For x = 1 To lCnt
            strRetA = Trim$(test.strA)
         Next
      Case 39
         strTest = strTest & strTab & "strRetA = Str(iTest)" & strTab & "'iTest is a local integer"
         strCode = "strRetA = Str(iTest)"
         lStart = timeGetTime()
         For x = 1 To lCnt
            strRetA = Str(iTest)
         Next
      Case 40
         strTest = strTest & strTab & "strRetA = Str$(iTest)" & strTab & "'iTest is a local integer"
         strCode = "strRetA = Str$(iTest)"
         lStart = timeGetTime()
         For x = 1 To lCnt
            strRetA = Str$(iTest)
         Next
      Case 41
         strTest = strTest & strTab & "Set C = cmdExit" & strTab & "'C Dimmed locally as Control"
         strCode = "Set C = cmdExit 'C dimmed as Control"
         lStart = timeGetTime()
         Dim C As Control
         For x = 1 To lCnt
            Set C = frmMain!cmdExit
         Next
      Case 42
         strTest = strTest & strTab & "Set Btn = cmdExit" & strTab & "'Btn Dimmed locally as CommandButton"
         strCode = "Set Btn = cmdExit 'C dimmed as Button"
         lStart = timeGetTime()
         Dim Btn As CommandButton
         For x = 1 To lCnt
            Set Btn = frmMain!cmdExit
         Next
      Case 43
         strTest = strTest & strTab & "iTest = frmMain!lblCount.Enabled"
         strCode = "iTest = frmMain!lblCount.Enabled"
         lStart = timeGetTime()
         For x = 1 To lCnt
            iTest = frmMain!lblCount.Enabled
         Next
      Case 44
         'unused
      Case 45
         strTest = strTest & strTab & "Debug.Print ""This is a Test"""
         strCode = "Debug.Print ""This is a Test"""
         lStart = timeGetTime()
         For x = 1 To lCnt
            Debug.Print "This is a Test"
         Next
      Case 46
         lCnt = ChangeLoops(5000)
         strTest = strTest & strTab & "Debug.Print ""This is a Test: "" & Format$(Now, ""mm/dd/yy hh:mm:ss"")"
         strCode = "Debug.Print ""This is a Test: "" & _" & vbCrLf & "Format$(Now, ""mm/dd/yy hh:mm:ss"")"
         lStart = timeGetTime()
         For x = 1 To lCnt
            Debug.Print "This is a Test: " & Format$(Now, "mm/dd/yy hh:mm:ss")
         Next
      Case 47
         strTest = strTest & strTab & "lTest = timeGetTime()"
         strCode = "lTest = timeGetTime()"
         lStart = timeGetTime()
         For x = 1 To lCnt
            lTest = timeGetTime()
         Next
      Case 48
         strTest = strTest & strTab & "frmMain!lblTest.Enabled = True"
         strCode = "frmMain!lblTest.Enabled = True"
         lStart = timeGetTime()
         For x = 1 To lCnt
            frmMain!lblTest.Enabled = True
         Next
      Case 49
         strTest = strTest & strTab & "frmMain!lblTest.Caption = ""Caption"""
         strCode = "frmMain!lblTest.Caption = ""Caption"""
         lStart = timeGetTime()
         For x = 1 To lCnt
            frmMain!lblTest.Caption = "Caption"
         Next
      Case 50
         lCnt = ChangeLoops(10000)
         strTest = strTest & strTab & "frmMain!lblTest.Move Width * Rnd, Top * Rnd" & vbCrLf & strTab & "'label is hidden prior to test"
         strCode = "lblTest.Move Width * Rnd, Top * Rnd"
         lStart = timeGetTime()
         iWidth = frmMain.Width
         iHeight = frmMain.ScaleHeight - frmMain!lblScroll.Top
         strCode = "frmMain!lblTest.Move iWidth * Rnd, iHeight * Rnd"
         lStart = timeGetTime()
         For x = 1 To lCnt
            frmMain!lblTest.Move iWidth * Rnd, iHeight * Rnd
         Next
      Case 51
         strTest = strTest & strTab & "iTest = frmMain!lblTest.Left"
         strCode = "iTest = frmMain!lblTest.Left"
         lStart = timeGetTime()
         For x = 1 To lCnt
            iTest = frmMain!lblTest.Left
         Next
      Case 52
         lCnt = ChangeLoops(1000)
         strTest = strTest & strTab & "frmMain!lblTest.Move iWidth * Rnd, iHeight * Rnd"
         strCode = "frmMain!lblTest.Move iWidth * Rnd, iHeight * Rnd"
         frmMain!lblTest.Visible = True
         iWidth = frmMain.Width
         iHeight = frmMain!lblScroll.Top
         lStart = timeGetTime()
         For x = 1 To lCnt
            frmMain!lblTest.Move iWidth * Rnd, iHeight * Rnd
         Next
      Case 53
         lCnt = ChangeLoops(1000)
         strTest = strTest & strTab & "iTest = DoEvents()"
         strCode = "iTest = DoEvents()"
         lStart = timeGetTime()
         For x = 1 To lCnt
            iTest = DoEvents()
         Next
      Case 54
         strTest = strTest & strTab & "iRet = T_NearPass1EmptyFunc(iTest)" & strTab & "' pass and returns an integer"
         strCode = "iRet = T_NearPass1EmptyFunc(iTest)"
         lStart = timeGetTime()
         For x = 1 To lCnt
            iRet = T_NearPass1EmptyFunc(iTest)
         Next
      Case 55
         strTest = strTest & strTab & "T_NearEmptySub" & strTab & "' lives in same module"
         strCode = "T_NearEmptySub"
         lStart = timeGetTime()
         For x = 1 To lCnt
            T_NearEmptySub
         Next
      Case 56
         lCnt = ChangeLoops(500)
         strTest = strTest & strTab & "Call T_Near32KStringArraySub()" & strTab & "' lives in same module"
         strCode = "Call T_Near32KStringArraySub"
         lStart = timeGetTime()
         For x = 1 To lCnt
            Call T_Near32KStringArraySub
         Next
      Case 57
         lCnt = ChangeLoops(1000)
         strTest = strTest & strTab & "Call T_Near32KIntArraySub()" & strTab & "' lives in same module"
         strCode = "Call T_Near32KIntArraySub"
         lStart = timeGetTime()
         For x = 1 To lCnt
            Call T_Near32KIntArraySub
         Next
       Case 58
         strTest = strTest & strTab & "Call T_Near30DoublesSub()" & strTab & "' lives in same module"
         strCode = "Call T_Near30DoublesSub"
         lStart = timeGetTime()
         For x = 1 To lCnt
            Call T_Near30DoublesSub
         Next
      Case 59
         strTest = strTest & strTab & "GoSub TestSub"
         strCode = "GoSub TestSub"
         lStart = timeGetTime()
         For x = 1 To lCnt
            GoSub TestSub
         Next
      Case 60
         strTest = strTest & strTab & "iTest = Instr(strRetA, ""F"")" & strTab & "'strRetA = ""ABCDEFGHIJKLMNLOP"""
         strCode = "iTest = Instr(strRetA, ""F"")"
         strRetA = "ABCDEFGHIJKLMNOP"
         lStart = timeGetTime()
         For x = 1 To lCnt
            iTest = InStr(strRetA, "F")
         Next
      Case 61
         strTest = strTest & strTab & "strRetB = Mid$(strRetA, 8, 1)" & strTab & "'strRetA = ""ABCDEFGHIJKLMNLOP"""
         strCode = "strRetB = Mid$(strRetA, 8, 1)"
         strRetA = "ABCDEFGHIJKLMNOP"
         lStart = timeGetTime()
         For x = 1 To lCnt
            strRetB = Mid$(strRetA, 8, 1)
         Next
   End Select
'
'  Evaluate the results...
'
   lEnd = timeGetTime()
   lResult = lEnd - lStart
   strResult1 = Format$(lResult, "#,##0") & " milliseconds"
   If (lResult / lCnt) * 1000 >= 1 Then
      strResult2 = Format$((lResult / lCnt) * 1000, "#,##0.00") & " microseconds"
   Else
      strResult2 = Format$((lResult / lCnt) * 1000000, "0") & " nanoseconds"
   End If
   
   If iTestType <> 0 Then '0 is the empty for loop test
      lStart = timeGetTime()
      For x = 1 To lCnt
      Next
      lEnd = timeGetTime()
      If ((lResult - (lEnd - lStart)) / lCnt) * 1000 >= 1 Then
         strResult3 = Format$(((lResult - (lEnd - lStart)) / lCnt) * 1000, "#,##0.00") & " microseconds"
      Else
         iNSecs = ((lResult - (lEnd - lStart)) / lCnt) * 1000000
         If iNSecs < 0 Then iNSecs = 0 'don't return negative result due to sampling error
         strResult3 = Format$(iNSecs, "0") & " nanoseconds"
      End If
   Else
      strResult3 = "N/A"
   End If
   
   strMsg = strTest & vbCrLf & strLine & vbCrLf & vbCrLf & "Elapsed Time for " & Format$(lCnt, "#,###") & " Iterations:  " & strResult1 & vbCrLf & vbCrLf & "Computed Time for 1 Iteration:  " & strResult2 & vbCrLf & vbCrLf & "Actual Time (Looping Factored Out):  " & strResult3
   If lResult < 10 Then
      strMsg = strMsg & vbCrLf & vbCrLf & "Note:  Computed time is probably not statistically valid" & vbCrLf & strTab & "     for samples of less than 10 milliseconds.  Try" & vbCrLf & strTab & "     increasing the number of iterations."
   Else
'
'     Print results if result file is open
'
      If giFile Then
         strTest = frmMain!lstTest.Text
         If Len(strTest) > 30 Then strTest = Left$(strTest, 30) & "..."
         Print #giFile, strTest; Tab(36); Format$(lCnt, "0"); Tab(46); strResult1; Tab(66); strResult3
      End If
   End If
'
'  Display the results
'
   Screen.MousePointer = vbDefault
   frmMain!lblTest.Visible = False
   MsgBox strMsg, , gstrTitle
   Exit Sub
   
TestSub:
'
'  This is for the the GoSub test
'
   Return
'
'  Done
'
End Sub

Private Sub T_Near30DoublesSub()

   Dim X0Test As Double
   Dim X1Test As Double
   Dim X2Test As Double
   Dim X3Test As Double
   Dim X4Test As Double
   Dim X5Test As Double
   Dim X6Test As Double
   Dim X7Test As Double
   Dim X8Test As Double
   Dim X9Test As Double
   Dim Y0Test As Double
   Dim Y1Test As Double
   Dim Y2Test As Double
   Dim Y3Test As Double
   Dim Y4Test As Double
   Dim Y5Test As Double
   Dim Y6Test As Double
   Dim Y7Test As Double
   Dim Y8Test As Double
   Dim Y9Test As Double
   Dim Z0Test As Double
   Dim Z1Test As Double
   Dim Z2Test As Double
   Dim Z3Test As Double
   Dim Z4Test As Double
   Dim Z5Test As Double
   Dim Z6Test As Double
   Dim Z7Test As Double
   Dim Z8Test As Double
   Dim Z9Test As Double

End Sub

Private Sub T_Near32KIntArraySub()

   Dim x() As Integer
   ReDim x(1 To 32000)
   
End Sub

Private Sub T_Near32KStringArraySub()

   Dim strTest() As String
   ReDim strTest(1 To 32000)
      
End Sub

Private Function T_NearPass1EmptyFunc(x As Integer) As Integer

End Function

Private Sub T_NearEmptySub()

End Sub

Private Sub T_NearPass1EmptySub(x As Integer)

End Sub

Private Sub T_NearPass4EmptySub(x As Integer, y As Long, z As Single, a As Double)

End Sub

Public Sub LoadTestList()
'
'  Load tests into the list box.  Add new tests by creating a
'  new item at the bottom of the With block with a distinct
'  name and ItemData value, then add the corresponding case
'  to the RunTest sub.
'
'  Some test slots are designated as "Unused"; these were once
'  defined but were either redundant or broken.  These slots
'  should be filled up with new and (hopefully) interesting tests.
'
   With frmMain!lstTest
      .AddItem "Empty For Loop"
      .ItemData(.NewIndex) = 0
      .AddItem "Increment a 16 Bit Counter"
      .ItemData(.NewIndex) = 1
      .AddItem "Increment a 32 Bit Counter"
      .ItemData(.NewIndex) = 2
      .AddItem "Increment a 32 Bit Real Value"
      .ItemData(.NewIndex) = 3
      .AddItem "Enable/Disable Error Trap #2 (Div by 0)"
      .ItemData(.NewIndex) = 4
      .AddItem "Enable/Disable Error Trap #1 (No Error)"
      .ItemData(.NewIndex) = 5
      .AddItem "Trapped Divide by Zero"
      .ItemData(.NewIndex) = 6
      .AddItem "Near Call to Empty Sub - Nothing Passed"
      .ItemData(.NewIndex) = 7
      .AddItem "Far Call to Empty Sub - Nothing Passed"
      .ItemData(.NewIndex) = 8
      .AddItem "Near Call to Empty Sub - Pass 1 Var"
      .ItemData(.NewIndex) = 9
      .AddItem "Near Call to Empty Sub - Pass 4 Vars"
      .ItemData(.NewIndex) = 10
      .AddItem "If Statement, One Line Format"
      .ItemData(.NewIndex) = 11
      .AddItem "If Statement, Two Line Format"
      .ItemData(.NewIndex) = 12
      .AddItem "Assign Numeric to Integer"
      .ItemData(.NewIndex) = 13
      .AddItem "Assign Constant to Integer"
      .ItemData(.NewIndex) = 14
      .AddItem "Unused #1"
      .ItemData(.NewIndex) = 15
      .AddItem "Calc Single, No Overflow Check"
      .ItemData(.NewIndex) = 16
      .AddItem "Unused #2"
      .ItemData(.NewIndex) = 17
      .AddItem "Unused #3"
      .ItemData(.NewIndex) = 18
      .AddItem "Enable/Disable Error Trap #3 (Overflow)"
      .ItemData(.NewIndex) = 19
      .AddItem "Calc Single, Check for Overflow"
      .ItemData(.NewIndex) = 20
      .AddItem "Unused #4"
      .ItemData(.NewIndex) = 21
      .AddItem "Absolute Value of Integer"
      .ItemData(.NewIndex) = 22
      .AddItem "Assign Variable to Integer"
      .ItemData(.NewIndex) = 23
      .AddItem "Enable/Disable Error Trap #4 (Overflow)"
      .ItemData(.NewIndex) = 24
      .AddItem "Redim Preserve Small Integer Array #1"
      .ItemData(.NewIndex) = 25
      .AddItem "Redim Preserve Small Integer Array #2"
      .ItemData(.NewIndex) = 26
      .AddItem "Redim Preserve Small Single Array #1"
      .ItemData(.NewIndex) = 27
      .AddItem "UBound of Small Integer Array"
      .ItemData(.NewIndex) = 28
      .AddItem "Format$ a Real Number"
      .ItemData(.NewIndex) = 29
      .AddItem "Format a Real Number"
      .ItemData(.NewIndex) = 30
      .AddItem "Reference Object Caption Property 1"
      .ItemData(.NewIndex) = 31
      .AddItem "Unused #5"
      .ItemData(.NewIndex) = 32
      .AddItem "Reference Object Caption Property 2"
      .ItemData(.NewIndex) = 33
      .AddItem "Assign String"
      .ItemData(.NewIndex) = 34
      .AddItem "RGB Function"
      .ItemData(.NewIndex) = 35
      .AddItem "QBColor Function"
      .ItemData(.NewIndex) = 36
      .AddItem "Trim Function"
      .ItemData(.NewIndex) = 37
      .AddItem "Trim$ Function"
      .ItemData(.NewIndex) = 38
      .AddItem "Str Function"
      .ItemData(.NewIndex) = 39
      .AddItem "Str$ Function"
      .ItemData(.NewIndex) = 40
      .AddItem "Set Generic Object Variable"
      .ItemData(.NewIndex) = 41
      .AddItem "Set Specific Object Variable"
      .ItemData(.NewIndex) = 42
      .AddItem "Reference Object Enabled Property"
      .ItemData(.NewIndex) = 43
      .AddItem "Unused #6"
      .ItemData(.NewIndex) = 44
      .AddItem "Debug.Print Line in EXE 1"
      .ItemData(.NewIndex) = 45
      .AddItem "Debug.Print Line in EXE 2"
      .ItemData(.NewIndex) = 46
      .AddItem "timeGetTime()"
      .ItemData(.NewIndex) = 47
      .AddItem "Set Enabled Property"
      .ItemData(.NewIndex) = 48
      .AddItem "Set Caption Property"
      .ItemData(.NewIndex) = 49
      .AddItem "Move Method (Hidden)"
      .ItemData(.NewIndex) = 50
      .AddItem "Reference Left Property"
      .ItemData(.NewIndex) = 51
      .AddItem "Move Method (Visible)"
      .ItemData(.NewIndex) = 52
      .AddItem "DoEvents()"
      .ItemData(.NewIndex) = 53
      .AddItem "Near Call to Empty Function - Pass 1 Var"
      .ItemData(.NewIndex) = 54
      .AddItem "Near Call to Empty Sub - Nothing Passed/No ""Call"""
      .ItemData(.NewIndex) = 55
      .AddItem "Near Call to Sub - Nothing Passed, 32K Local String Array"
      .ItemData(.NewIndex) = 56
      .AddItem "Near Call to Sub - Nothing Passed, 32K Local Integer Array"
      .ItemData(.NewIndex) = 57
      .AddItem "Near Call to Sub - Nothing Passed, 30 Local Doubles"
      .ItemData(.NewIndex) = 58
      .AddItem "GoSub"
      .ItemData(.NewIndex) = 59
      .AddItem "Instr Function"
      .ItemData(.NewIndex) = 60
      .AddItem "Mid$ Function"
      .ItemData(.NewIndex) = 61
      
      .ListIndex = 0 'select first item by default
   End With
'
'  Done
'
End Sub






